# discord.py-bot-cli

discord.py-cli is a CLI that helps in making Discord bots easily. It is used with discord.py and can be installed with PIP.

## Features

* Auto check-and-update. No manual updation.
* Variations in project making: .env and no .env file projects.
* Hosting: Git and Heroku, and Github and Heroku.
* Commands to simplify tasks.

## Installation

To install discord.py-bot-cli use this command in terminal:

```
pip install discord.py-bot-cli
```

## Commands

This CLI has 4 commands.

`init`: Initializes a Discord bot project.

`cog`: Creates a cog file and adds setup.

`deploy`: Deploys the bot (Use with Git and Heroku).

`wrap`: Creates a requirements file (Use with Github and Heroku).

And to use these, type `dcpy` followed by the command.

To know more about commands and options, do `dcpy --help`.